# Django Test Package

A simple test package that provides a hello function.

## Installation

```bash
pip install django-testpkg-prakash
```

## Usage

```python
from testpkg.hello import say_hello

print(say_hello())
```

